@@ -21,13 +21,24 @@ import shutil
 
 import json
 
-# Attempt to load in JXL support
-try:
-     import pillow_jxl
-except ImportError:
-     pass
 from PIL import Image
 
+try:
+    from pillow_heif import register_heif_opener
+    register_heif_opener()
+except ImportError:
+    print('Warning: HEIF/HEIC image support not available. Install pillow-heif.')
+
+try:
+    import pillow_avif
+except ImportError:
+    print('Warning: AVIF image support not available. Install pillow-avif.')
+
+try:
+    import pillow_jxl
+except ImportError:
+    print('JPEG XL (JXL) support not available. Install pillow-jxl if needed.')
+
 import gi
 
 gi.require_version('Gtk', '3.0')
